@@ -29,14 +29,13 @@ def test_inspect_basic(simple_script: PipTestEnvironment) -> None:
     """
     result = simple_script.pip("inspect")
     report = json.loads(result.stdout)
-    installed = report["installed"]
-    assert len(installed) == 5
-    installed_by_name = {i["metadata"]["name"]: i for i in installed}
+    installed_by_name = {i["metadata"]["name"]: i for i in report["installed"]}
+    # Coverage is only installed if test coverage is being collected.
+    installed_by_name.pop("coverage", None)
+    assert len(installed_by_name) == 3
     assert installed_by_name.keys() == {
         "pip",
         "setuptools",
-        "wheel",
-        "coverage",
         "simplewheel",
     }
     assert installed_by_name["simplewheel"]["metadata"]["version"] == "1.0"
